
Changelog
=========

0.3.0 (2017-06-08)
------------------

* Added "size" and "last_modified" fields to output
* Changed output to a table
* Stylized output for easier reading and comprehension

0.2.0 (2017-06-07)
------------------

* Added Unicode-based icons
* Improved Python 3 support

0.1.0 (2017-05-26)
------------------

* First release on PyPI.
